@@ -20,6 +20,7 @@
 #include "trackpickerdialog.h"
 #include "tag.h"
 #include "collectionlist.h"
+#include "tagtransactionmanager.h"
 
 #include <kmainwindow.h>
 #include <kapplication.h>
@@ -57,7 +58,7 @@ void MusicBrainzLookup::collision()
 void MusicBrainzLookup::error()
 {
     KTRMLookup::error();
-    message(i18n("TRM generation failed"));
+    message(i18n("Error connecting to MusicBrainz server."));
 }
 
 void MusicBrainzLookup::message(const QString &s) const
@@ -84,30 +85,30 @@ void MusicBrainzLookup::confirmation()
     queue.append(qMakePair(m_file, results()));
 
     while(!queue.isEmpty()) {
-        FileHandle file = queue.first().first;
-        KTRMResultList results = queue.first().second;
+        QPair<FileHandle, KTRMResultList> item = queue.first();
+        FileHandle file = item.first;
+        KTRMResultList results = item.second;
         TrackPickerDialog dialog(file.fileInfo().fileName(), results);
 
         if(dialog.exec() == QDialog::Accepted && !dialog.result().isEmpty()) {
-
             KTRMResult result = dialog.result();
+            Tag *tag = TagTransactionManager::duplicateTag(file.tag());
 
             if(!result.title().isEmpty())
-                file.tag()->setTitle(result.title());
+                tag->setTitle(result.title());
             if(!result.artist().isEmpty())
-                file.tag()->setArtist(result.artist());
+                tag->setArtist(result.artist());
             if(!result.album().isEmpty())
-                file.tag()->setAlbum(result.album());
+                tag->setAlbum(result.album());
             if(result.track() != 0)
-                file.tag()->setTrack(result.track());
+                tag->setTrack(result.track());
             if(result.year() != 0)
-                file.tag()->setYear(result.year());
+                tag->setYear(result.year());
 
-            file.tag()->save();
-
-            CollectionList::instance()->slotRefreshItem(file.absFilePath());
+            PlaylistItem *item = CollectionList::instance()->lookup(file.absFilePath());
+            TagTransactionManager::instance()->changeTagOnItem(item, tag);
+            TagTransactionManager::instance()->commit();
         }
-
         queue.pop_front();
     }
 }
