@@ -26,10 +26,13 @@
 #include <qfont.h>
 #include <qfontmetrics.h>
 #include <qrect.h>
+#include <qtextcodec.h>
+
+#include <kconfig.h>
 #include <kglobal.h>
 #include <kglobalsettings.h>
 #include <kinstance.h>
-#include <kconfig.h>
+#include <klocale.h>
 #include "version.h"
 
 
@@ -49,6 +52,8 @@ KDisplayText::KDisplayText(QWidget *parent,const char *name) : QScrollView(paren
   first_line=NULL;
   cursor=NULL;
   nlines=0;
+  lyrics_codec=KGlobal::locale()->codecForEncoding();
+
   viewport()->setBackgroundColor(QColor (110,110,110));
 //  setBackgroundMode(NoBackground);
   KConfig *kcfg=KGlobal::instance()->config();
@@ -209,15 +214,15 @@ void KDisplayText::calculatePositions(void)
                         tmpx=5;
 
                         tmp->xpos=tmpx;
-                        if (tmp->spev->text[0]!=0) tmpw=qfmetr->width(&tmp->spev->text[1]);
+                        if (tmp->spev->text[0]!=0) tmpw=qfmetr->width(lyrics_codec->toUnicode(&tmp->spev->text[1]));
 				else tmpw=0;
-                        tmp->r=qfmetr->boundingRect(&tmp->spev->text[1]);
+                        tmp->r=qfmetr->boundingRect(lyrics_codec->toUnicode(&tmp->spev->text[1]));
                     }
                     else
                     {
                         tmp->xpos=tmpx;
-                        tmpw=qfmetr->width(tmp->spev->text);
-                        tmp->r=qfmetr->boundingRect(tmp->spev->text);
+                        tmpw=qfmetr->width(lyrics_codec->toUnicode(tmp->spev->text));
+                        tmp->r=qfmetr->boundingRect(lyrics_codec->toUnicode(tmp->spev->text));
                     }
 	// We add 5 pixels above, below and to the right because of a
 	// problem with latest released Xft
@@ -236,7 +241,7 @@ void KDisplayText::calculatePositions(void)
         maxX[(typeoftextevents==1)?0:1]=maxx+10;
         maxY[(typeoftextevents==1)?0:1]=
 		nlines_[(typeoftextevents==1)?0:1]*lineSpacing+descent+10;
- 
+
         if (typeoftextevents==1) typeoftextevents=5;
         else fin=1;
     }
@@ -279,7 +284,7 @@ void KDisplayText::drawContents(QPainter *p, int /*clipx*/, int clipy, int /*cli
        nlinestodraw++;
        t=t->next;
        }
-    
+
     i=0;
     while ((i<nlinestodraw)&&(tmpl!=NULL))
     {
@@ -287,18 +292,18 @@ void KDisplayText::drawContents(QPainter *p, int /*clipx*/, int clipy, int /*cli
         while ((tmp!=NULL)&&(tmp->spev->type!=typeoftextevents)) tmp=tmp->next;
         while (tmp!=NULL)
         {
-            if ( colorplayed && 
+            if ( colorplayed &&
                  //	(tmp->spev->absmilliseconds>=cursor->spev->absmilliseconds))
                  (tmp->spev->id>=cursor->spev->id))
             {
                 p->setPen(black);
                 colorplayed=0;
-            }	
-            
+            }
+
             if (IsLineFeed(tmp->spev->text[0],tmp->spev->type))
-                p->drawText(tmp->xpos,tmpl->ypos,&tmp->spev->text[1]);
+                p->drawText(tmp->xpos,tmpl->ypos,lyrics_codec->toUnicode(&tmp->spev->text[1]));
             else
-                p->drawText(tmp->xpos,tmpl->ypos,tmp->spev->text);
+                p->drawText(tmp->xpos,tmpl->ypos,lyrics_codec->toUnicode(tmp->spev->text));
 
 #ifdef DRAW_BOUNDING_RECTS
 	    p->setPen(red);
@@ -311,13 +316,13 @@ void KDisplayText::drawContents(QPainter *p, int /*clipx*/, int clipy, int /*cli
         i++;
         tmpl=tmpl->next;
     }
-    
+
 }
 
 
 void KDisplayText::resizeEvent(QResizeEvent *e)
 {
-    QScrollView::resizeEvent(e);  
+    QScrollView::resizeEvent(e);
     nvisiblelines=visibleHeight()/qfmetr->lineSpacing();
     if ( (nlines>nvisiblelines) || (nvisiblelines==0) )
         resizeContents(maxX[(typeoftextevents==1)?0:1],maxY[(typeoftextevents==1)?0:1]);
@@ -614,9 +619,22 @@ void KDisplayText::timerEvent(QTimerEvent *e)
     
 }
 
-
-/*QSize KDisplayText::sizeHint()
+void KDisplayText::setLyricsEncoding(const QString &enc)
 {
-return QSize(400,200);
-}*/
+  QTextCodec *newcodec;
+  if (enc.isEmpty())
+    newcodec=KGlobal::locale()->codecForEncoding();
+  else
+    newcodec=QTextCodec::codecForName(enc.latin1()); 
+
+  if (newcodec!=lyrics_codec)
+  {
+    if (newcodec)
+    {
+      lyrics_codec=newcodec;
+      fontChanged();
+    }
+  }      
+}
+
 #include "kdisptext.moc"
