@@ -27,102 +27,26 @@
 #define MIXER_H
 
 #include <qstring.h>
+#include <qtimer.h>
 #include <qobject.h>
 #include <qintdict.h>
 #include <qptrlist.h>
 
 #include "volume.h"
 #include "mixerIface.h"
-
+#include "mixset.h"
+#include "mixdevice.h"
 
 class Volume;
 class KConfig;
 
-class MixDevice
-{
-   public:
-      // For each ChannelType a special icon exists
-      enum ChannelType {AUDIO = 1, BASS, CD, EXTERNAL, MICROPHONE,
-			MIDI, RECMONITOR, TREBLE, UNKNOWN, VOLUME,
-			VIDEO, SURROUND, HEADPHONE, DIGITAL, AC97 };
-
-      // The DeviceCategory tells, how "important" a MixDevice is. See m_category.
-      // It is used in bitmasks, so you must use values of 2^n .
-      enum DeviceCategory { BASIC=0x01, PRIMARY=0x02, SECONDARY=0x04, SWITCH=0x08, ALL=0xff };
-
-    
-      MixDevice(int num, Volume vol, bool recordable,
-		QString name, ChannelType type = UNKNOWN, DeviceCategory category = BASIC );
-      MixDevice(const MixDevice &md);
-      ~MixDevice() {};
-
-      int num() const   	         { return m_num; };
-      QString	name() const         { return m_name; };
-      bool isStereo() const        { return (m_volume.channels() > 1); };
-      bool isRecordable() const    { return m_recordable; };
-      bool isRecsrc() const        { return m_recsrc; };
-      bool isMuted() const         { return m_volume.isMuted(); };
-
-      void setMuted(bool value)            { m_volume.setMuted( value ); };
-      void setRecsrc(bool value)           { m_recsrc = value; };
-      void setVolume( Volume volume ) { m_volume = volume; };
-      void setVolume( int channel, int volume );
-      int getVolume( int channel ) const;
-      Volume getVolume() const { return m_volume; };
-      int rightVolume() const;
-      int leftVolume() const;
-
-      void read( KConfig *config, const QString& grp );
-      void write( KConfig *config, const QString& grp );
-
-      void setType( ChannelType channeltype ) { m_type = channeltype; };
-      ChannelType type() { return m_type; };
-
-      DeviceCategory category() { return m_category; };
-      static DeviceCategory type2category( ChannelType ct);
-
-   protected:
-      Volume m_volume;
-      ChannelType m_type;
-      // The DeviceCategory tells, how "important" a MixDevice is.
-      // The driver (e.g. mixer_oss.cpp) must set this value. It is
-      // used for deciding what Sliders to show and for distributing
-      // the sliders. It is advised to use the following categories:
-      // BASIC:     Master, PCM
-      // PRIMARY:   CD, Headphone, Microphone, Line
-      // SECONDARY: All others
-      // SWITCH:    All devices which only have a On/Off-Switch
-      int m_num; // ioctl() device number of mixer
-      bool m_recordable; // Can it be recorded?
-      bool m_recsrc; // Is it an actual record source?
-      DeviceCategory m_category; //  category
-      QString m_name;	// Ascii channel name
-};
-
-
-class MixSet : public QPtrList<MixDevice>
-{
-   public:
-      void read( KConfig *config, const QString& grp );
-      void write( KConfig *config, const QString& grp );
-
-      void clone( MixSet &orig );
-
-      QString name() { return m_name; };
-      void setName( const QString &name ) { m_name = name; };
-
-   private:
-      QString m_name;
-};
-
-
 class Mixer : public QObject, virtual public MixerIface
 {
       Q_OBJECT
 
    public:
       enum MixerError { ERR_PERM=1, ERR_WRITE, ERR_READ, ERR_NODEV, ERR_NOTSUPP,
-			ERR_OPEN, ERR_LASTERR, ERR_NOMEM, ERR_INCOMPATIBLESET };
+			ERR_OPEN, ERR_LASTERR, ERR_NOMEM, ERR_INCOMPATIBLESET, ERR_MIXEROPEN };
 
       Mixer( int device = -1, int card = -1 );
       virtual ~Mixer() {};
@@ -130,8 +54,8 @@ class Mixer : public QObject, virtual public MixerIface
       /// Static function. This function must be overloaded by any derived mixer class
       /// to create and return an instance of the derived class.
       static int getDriverNum();
-      static Mixer* getMixer( int driver, int device = 0, int card = 0 );
-      static Mixer* getMixer( int driver, MixSet set,int device = 0, int card = 0 );
+      static Mixer* getMixer( int driver, int device = 0 );
+      //static Mixer* getMixer( int driver, MixSet set,int device = 0 );
 
       void volumeSave( KConfig *config );
       void volumeLoad( KConfig *config );
@@ -156,16 +80,24 @@ class Mixer : public QObject, virtual public MixerIface
       /// Derived classes can override this method to produce platform
       /// specific error descriptions.
       virtual QString errorText(int mixer_error);
+      /// Returns the last error number
+      int getErrno() const;
+
+      /// Returns a detailed state message after errors. Only for diagnostic purposes, no i18n.
+      QString& stateMessage() const;
+
       virtual QString mixerName();
 
+      // Returns the name of the driver, e.g. "OSS" or "ALSA0.9"
+      QString driverName();
+      static QString driverName(int num);
+
       /// set/get mixer number used to identify mixers with equal names
       void setMixerNum( int num );
       int mixerNum();
 
       /// get the actual MixSet
       virtual MixSet getMixSet() { return m_mixDevices; };
-      /// Write a given MixSet to hardware
-      virtual void writeMixSet( MixSet set );
 
       /// Set the record source(s) according to the given device mask
       /// The default implementation does nothing.
@@ -182,37 +114,51 @@ class Mixer : public QObject, virtual public MixerIface
       /// Reads the volume of the given device into VolLeft and VolRight.
       /// Abstract method! You must implement it in your dericved class.
       virtual int readVolumeFromHW( int devnum, Volume &vol ) = 0;
-
+      virtual bool prepareUpdate();
+      virtual void setEnumIdHW(int mixerIdx, unsigned int);
+      virtual unsigned int enumIdHW(int mixerIdx);
 
       /// DCOP oriented methods (look at mixerIface.h for the descriptions)
-      virtual void setVolume( int channeltype, int percentage );
+      virtual void setVolume( int deviceidx, int percentage );
+      virtual void setAbsoluteVolume( int deviceidx, long absoluteVolume );
       virtual void setMasterVolume( int percentage );
 
-      virtual void increaseVolume( int channeltype );
-      virtual void decreaseVolume( int channeltype );
+      virtual void increaseVolume( int deviceidx );
+      virtual void decreaseVolume( int deviceidx );
 
-      virtual int volume( int channeltype );
+      virtual long absoluteVolume( int deviceidx );
+      virtual long absoluteVolumeMin( int deviceidx );
+      virtual long absoluteVolumeMax( int deviceidx );
+      virtual int volume( int deviceidx );
       virtual int masterVolume();
 
-      virtual void setMute( int channeltype, bool on );
-      virtual bool mute( int channeltype );
-      virtual void setRecordSource( int deviceidx, bool on );
+
+
+      virtual void setMute( int deviceidx, bool on );
+      virtual bool mute( int deviceidx );
+      virtual void toggleMute( int deviceidx );
       virtual bool isRecordSource( int deviceidx );
 
       virtual bool isAvailableDevice( int deviceidx );
 
+      void commitVolumeChange( MixDevice* md );
+
+      virtual bool hasBrokenRecSourceHandling();
+
    public slots:
       /// Writes the given volumes in the given device
       /// Abstract method! You must implement it in your dericved class.
-      virtual int writeVolumeToHW( int devnum, Volume volume ) = 0;
+      virtual int writeVolumeToHW( int devnum, Volume &volume ) = 0;
       virtual void readSetFromHW();
+      void readSetFromHWforceUpdate() const;
+      virtual void setRecordSource( int deviceidx, bool on );
 
       virtual void setBalance(int balance); // sets the m_balance (see there)
-      virtual void setRecsrc( int devnum, bool on = true);
 
    signals:
-      void newBalance( Volume );
+      void newBalance( Volume& );
       void newRecsrc( void );
+      void newVolumeLevels(void);
 
    protected:
       int m_devnum;
@@ -230,11 +176,14 @@ class Mixer : public QObject, virtual public MixerIface
       /// gives you a usable name, use that name.
       QString m_mixerName;
 
+      QTimer* _pollingTimer;
+
       // mixer number to identify mixers with equal name correctly (set by the client)
       int m_mixerNum;
 
       bool m_isOpen;
       int m_balance; // from -100 (just left) to 100 (just right)
+      int     _errno;
 
       // All mix devices of this phyisical device.
       MixSet m_mixDevices;
@@ -242,8 +191,10 @@ class Mixer : public QObject, virtual public MixerIface
       QPtrList<MixSet> m_profiles;
 
    public:
-      int setupMixer() { return setupMixer( m_mixDevices ); };
       int setupMixer( MixSet set );
+
+   private:
+      mutable bool _readSetFromHWforceUpdate;
 };
 
 #endif
