@@ -1,7 +1,7 @@
 /*
  *              KMix -- KDE's full featured mini mixer
  *
- *              $Id: mixer_oss.cpp,v 1.27.2.1 2003/05/01 15:17:45 helio Exp $
+ *              $Id: mixer_oss.cpp,v 1.39 2004/11/23 16:49:59 helio Exp $
  *
  *              Copyright (C) 1996-2000 Christian Esken
  *                        esken@kde.org
@@ -79,18 +79,17 @@ Mixer* OSS_getMixer( int device, int card )
 {
   Mixer *l_mixer;
   l_mixer = new Mixer_OSS( device, card );
-  l_mixer->setupMixer();
   return l_mixer;
 }
 
+/*
 Mixer* OSS_getMixerSet( MixSet set, int device, int card )
 {
   Mixer *l_mixer;
   l_mixer = new Mixer_OSS( device, card );
-  l_mixer->setupMixer( set );
   return l_mixer;
 }
-
+*/
 
 Mixer_OSS::Mixer_OSS(int device, int card) : Mixer(device, card)
 {
@@ -143,10 +142,10 @@ int Mixer_OSS::openMixer()
                   Volume vol( stereodevs & ( 1 << idx ) ? 2 : 1, maxVolume);
                   readVolumeFromHW( idx, vol );
                   MixDevice* md =
-                    new MixDevice( idx, vol, recmask & ( 1 << idx ),
+                    new MixDevice( idx, vol, recmask & ( 1 << idx ), true,
                                    i18n(MixerDevNames[idx]),
                                    MixerChannelTypes[idx]);
-                  md->setRecsrc( isRecsrcHW( idx ) );
+                  md->setRecSource( isRecsrcHW( idx ) );
                   m_mixDevices.append( md );
                 }
               idx++;
@@ -260,14 +259,17 @@ bool Mixer_OSS::setRecsrcHW( int devnum, bool on )
 
 bool Mixer_OSS::isRecsrcHW( int devnum )
 {
-  int i_recsrc;
-  if (ioctl(m_fd, SOUND_MIXER_READ_RECSRC, &i_recsrc) == -1)
-    errormsg(Mixer::ERR_READ);
-
-  return i_recsrc & (1 << devnum );
+	bool isRecsrc = false;
+	int recsrcMask;
+	if (ioctl(m_fd, SOUND_MIXER_READ_RECSRC, &recsrcMask) == -1)
+		errormsg(Mixer::ERR_READ);
+	else {
+		// test if device bit is set in record bit mask
+		isRecsrc =  ( (recsrcMask & ( 1<<devnum)) != 0 );
+	}
+	return isRecsrc;
 }
 
-
 int Mixer_OSS::readVolumeFromHW( int devnum, Volume &vol )
 {
   if( vol.isMuted() ) return 0; // Don't alter volume when muted
@@ -281,20 +283,21 @@ int Mixer_OSS::readVolumeFromHW( int devnum, Volume &vol )
   else
     {
       vol.setVolume( Volume::LEFT, (volume & 0x7f));
-      if( vol.channels() > 1 )
+      if( vol.count() > 1 )
         vol.setVolume( Volume::RIGHT, ((volume>>8) & 0x7f));
-      return 0;
+      //fprintf(stderr, "Mixer_OSS::readVolumeFromHW(%i,vol) set vol %i %i\n", devnum,  vol.getVolume(Volume::LEFT), vol.getVolume(Volume::RIGHT));
+	return 0;
     }
 }
 
 
 
-int Mixer_OSS::writeVolumeToHW( int devnum, Volume vol )
+int Mixer_OSS::writeVolumeToHW( int devnum, Volume &vol )
 {
   int volume;
   if( vol.isMuted() ) volume = 0;
   else
-    if ( vol.channels() > 1 )
+    if ( vol.count() > 1 )
       volume = vol[ Volume::LEFT ] + ((vol[ Volume::RIGHT ])<<8);
     else
       volume = vol[ Volume::LEFT ];
@@ -304,3 +307,8 @@ int Mixer_OSS::writeVolumeToHW( int devnum, Volume vol )
 
   return 0;
 }
+
+QString OSS_getDriverName() {
+	return "OSS";
+}
+
