@@ -1,5 +1,5 @@
 /*
- * $Id: cdinfo.c,v 1.7 2003/12/06 10:41:09 aseigo Exp $
+ * $Id: cdinfo.c,v 1.8 2004/07/23 11:47:58 wheeler Exp $
  * 
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -73,7 +73,7 @@ int info_modified;
  * entry in the track list -- 0 will make this the first track, 1 the second,
  * etc.  The new entry will be zeroed out.
  */
-void
+static void
 insert_trackinfo(int num)
 {
 	struct wm_trackinfo *newtrk;
@@ -275,7 +275,7 @@ listentry( int num )
 {
 	static char	buf[600];
 	const char *name;
-    char* tracknum[20];
+    char tracknum[20];
 	int		digits;
 	int		sdigits;
 
