@@ -1,7 +1,7 @@
 #ifndef WM_CDDB_H
 #define WM_CDDB_H
 /*
- * $Id: wm_cddb.h,v 1.3 2003/03/06 19:56:37 kernalex Exp $
+ * $Id: wm_cddb.h,v 1.4 2004/11/14 23:11:30 mueller Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -25,12 +25,6 @@
  *
  */
 
-
-extern struct wm_cddb cddb;
-extern int cur_cddb_protocol;
-extern char *cur_cddb_server, *cur_cddb_mail_adress,
-	*cur_cddb_path_to_cgi, *cur_cddb_proxy_server;
-
 unsigned long cddb_discid(void);
 void cddb_struct2cur(void);
 void cddb_cur2struct(void);
