@@ -1,5 +1,5 @@
 /*
- * $Id: plat_linux.c,v 1.31.2.1 2004/02/28 14:54:28 mueller Exp $
+ * $Id: plat_linux.c,v 1.37 2005/02/01 20:12:07 aseigo Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -117,8 +117,6 @@ int	max_volume = 255;
 int mixer;
 char mixer_dev_name[20] = "/dev/mixer";
 #endif
-/*const char *cddaslave_path = "/home/kernalex/devel/kdemultimedia-3.0.6/kscd/libwm/.libs/cddaslave";*/
-const char *cddaslave_path = "cddaslave";
 
 /*-------------------------------------------------------*
  *
@@ -156,21 +154,10 @@ wmcd_open( struct wm_drive *d )
   }
 
   fd = open(d->cd_device, O_RDONLY | O_NONBLOCK);
-
-  if (fd < 0) {
-    if (errno == EACCES) {
-      return -EACCES;
-    }
-    /* Hack proposed by Carey Evans, introduced by Debian maintainer :
-     * treat EIO like ENXIO since some Linux drives do never return ENXIO
-     * ENOMEDIUM is returned by Kernel 2.2.x unified drivers.
-     */
-    else if ((errno != ENXIO) && (errno != EIO) && (errno != ENOMEDIUM)) {
-      return (-6);
-    }
-    /* No CD in drive. */
-    return 1;
-  }
+  wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "wmcd_open(): device=%s fd=%d\n", d->cd_device, fd);
+  
+  if (fd < 0)
+    return -errno;
 
   /* Now fill in the relevant parts of the wm_drive structure. */
   d->fd = fd;
@@ -375,89 +362,118 @@ int
 gen_get_drive_status( struct wm_drive *d, int oldmode,
   int *mode, int *pos, int *track, int *ind )
 {
-  struct cdrom_subchnl		sc;
+  struct cdrom_subchnl sc;
+  int ret;
   
 #ifdef SBPCD_HACK
   static int prevpos = 0;
 #endif
   
-  /* If we can't get status, the CD is ejected, so default to that. */
-  *mode = WM_CDM_EJECTED;
   
   /* Is the device open? */
-  if (d->fd < 0)
-    {
-      switch (wmcd_open(d))
-	{
-	case -1:	/* error */
-	  return (-1);
-	case 1:		/* retry */
-	  return (0);
-	}
+  if (d->fd < 0) {
+    ret = wmcd_open(d);
+    if(ret < 0) /* error */
+      return ret;
+          
+    if(ret == 1) {
+      /* retry */
+      *mode = WM_CDM_UNKNOWN;
+      return 0;
     }
- 
-#if defined(BUILD_CDDA)
-  if (oldmode == WM_CDM_PAUSED || oldmode == WM_CDM_PLAYING || oldmode == WM_CDM_STOPPED) {
-       CDDARETURN(d) cdda_get_drive_status(d, oldmode, mode, pos, track, ind);
   }
-#endif
 
   /* Try to get rid of the door locking    */
   /* Don't care about return value. If it  */
   /* works - fine. If not - ...            */
-  ioctl( d->fd, CDROM_LOCKDOOR, 0 ); 
- 
+  ioctl(d->fd, CDROM_LOCKDOOR, 0); 
+  
+  *mode = WM_CDM_UNKNOWN;
+  
   sc.cdsc_format = CDROM_MSF;
  
-  if (ioctl(d->fd, CDROMSUBCHNL, &sc))
-    return 1;
-  
-  switch (sc.cdsc_audiostatus) {
-  case CDROM_AUDIO_PLAY:
-    *mode = WM_CDM_PLAYING;
-    *track = sc.cdsc_trk;
-    *ind = sc.cdsc_ind;
-    *pos = sc.cdsc_absaddr.msf.minute * 60 * 75 +
-      sc.cdsc_absaddr.msf.second * 75 +
-      sc.cdsc_absaddr.msf.frame;
-#ifdef SBPCD_HACK
-    if( *pos < prevpos )
-      {
-	if( (prevpos - *pos) < 75 )
-	  {
-	    *mode = WM_CDM_TRACK_DONE;
-	  }
-      }
-    
-    prevpos = *pos;
+#if defined(BUILD_CDDA)
+  IFCDDA(d) {
+    if(!cdda_get_drive_status(d, oldmode, mode, pos, track, ind)) {
+      if(*mode == WM_CDM_STOPPED)
+        *mode = WM_CDM_UNKNOWN; /* dont believe */
+    }
+  } else
 #endif
-    break;
-    
-  case CDROM_AUDIO_PAUSED:
-  case CDROM_AUDIO_NO_STATUS:
-  case CDROM_AUDIO_INVALID: /**/
-    if (oldmode == WM_CDM_PLAYING || oldmode == WM_CDM_PAUSED)
-      {
-	*mode = WM_CDM_PAUSED;
-	*track = sc.cdsc_trk;
-	*ind = sc.cdsc_ind;
-	*pos = sc.cdsc_absaddr.msf.minute * 60 * 75 +
-	  sc.cdsc_absaddr.msf.second * 75 +
-	  sc.cdsc_absaddr.msf.frame;
+  if(!ioctl(d->fd, CDROMSUBCHNL, &sc)) {
+    switch (sc.cdsc_audiostatus) {
+    case CDROM_AUDIO_PLAY:
+      *mode = WM_CDM_PLAYING;
+      *track = sc.cdsc_trk;
+      *ind = sc.cdsc_ind;
+      *pos = sc.cdsc_absaddr.msf.minute * 60 * 75 +
+        sc.cdsc_absaddr.msf.second * 75 +
+        sc.cdsc_absaddr.msf.frame;
+#ifdef SBPCD_HACK
+      if( *pos < prevpos ) {
+        if( (prevpos - *pos) < 75 ) {
+          *mode = WM_CDM_TRACK_DONE;
+        }
       }
-    else
-      *mode = WM_CDM_STOPPED;
-    break;
     
-  case CDROM_AUDIO_COMPLETED:
-    *mode = WM_CDM_TRACK_DONE; /* waiting for next track. */
-    break;
+      prevpos = *pos;
+#endif
+      break;
     
-  default:
-    *mode = WM_CDM_UNKNOWN;
-    break;
+    case CDROM_AUDIO_PAUSED:
+      if (oldmode == WM_CDM_PLAYING || oldmode == WM_CDM_PAUSED) {
+        *mode = WM_CDM_PAUSED;
+        *track = sc.cdsc_trk;
+        *ind = sc.cdsc_ind;
+        *pos = sc.cdsc_absaddr.msf.minute * 60 * 75 +
+          sc.cdsc_absaddr.msf.second * 75 +
+          sc.cdsc_absaddr.msf.frame;
+      } else
+        *mode = WM_CDM_STOPPED;
+      break;
+    
+    case CDROM_AUDIO_NO_STATUS:
+        *mode = WM_CDM_STOPPED;
+      break;
+
+    case CDROM_AUDIO_COMPLETED:
+      *mode = WM_CDM_TRACK_DONE; /* waiting for next track. */
+      break;
+    
+    case CDROM_AUDIO_INVALID: /**/
+    default:
+      *mode = WM_CDM_UNKNOWN;
+      break;
+    }
   }
   
+  if(WM_CDS_NO_DISC(*mode)) {
+    /* verify status of drive */
+    ret = ioctl(d->fd, CDROM_DRIVE_STATUS, 0/* slot */);
+    if(ret == CDS_DISC_OK)
+      ret = ioctl(d->fd, CDROM_DISC_STATUS, 0);
+    switch(ret) {
+    case CDS_NO_DISC:
+      *mode = WM_CDM_NO_DISC;
+      break;
+    case CDS_TRAY_OPEN:
+      *mode = WM_CDM_EJECTED;
+      break;
+    case CDS_AUDIO:
+    case CDS_MIXED:
+      *mode = WM_CDM_STOPPED;
+      break;
+    case CDS_DRIVE_NOT_READY:
+    case CDS_NO_INFO:
+    case CDS_DATA_1:
+    case CDS_DATA_2:
+    case CDS_XA_2_1:
+    case CDS_XA_2_2:
+    default:
+      *mode = WM_CDM_UNKNOWN;
+    }
+  }
+
   return (0);
 } /* gen_get_drive_status */
 
@@ -504,7 +520,7 @@ gen_get_trackinfo(struct wm_drive *d, int track, int *data, int *startframe)
 int
 gen_get_cdlen(struct wm_drive *d, int *frames)
 {
-  int		tmp;
+  int tmp;
 
   return gen_get_trackinfo( d, CDROM_LEADOUT, &tmp, frames);
 } /* gen_get_cdlen() */
@@ -706,12 +722,24 @@ scale_volume( int vol, int max )
 {
 #ifdef CURVED_VOLUME
   return ((max * max - (max - vol) * (max - vol)) *
-	  (max_volume - min_volume) / (max * max) + min_volume);                        
+    (max_volume - min_volume) / (max * max) + min_volume);                        
 #else
   return ((vol * (max_volume - min_volume)) / max + min_volume);
 #endif        
 } /* scale_volume() */
 
+static int
+unscale_volume( int vol, int max )
+{
+#ifdef CURVED_VOLUME
+  /* FIXME do it simpler */
+  int tmp = (((max_volume - min_volume - vol) * max * max) - (vol + min_volume));
+  return max - sqrt((tmp/(max_volume - min_volume)));                        
+#else
+  return (((vol - min_volume) * max) / (max_volume - min_volume));
+#endif        
+} /* unscale_volume() */
+
 /*---------------------------------------------------------------------*
  * Set the volume level for the left and right channels.  Their values
  * range from 0 to 100.
@@ -719,7 +747,7 @@ scale_volume( int vol, int max )
 int
 gen_set_volume( struct wm_drive *d, int left, int right )
 {
-  struct	cdrom_volctrl v;
+  struct cdrom_volctrl v;
   
   CDDARETURN(d) cdda_set_volume(d, left, right);
 
@@ -740,10 +768,18 @@ gen_set_volume( struct wm_drive *d, int left, int right )
 int
 gen_get_volume( struct wm_drive *d, int *left, int *right )
 {
+  struct cdrom_volctrl v;
+  
   CDDARETURN(d) cdda_get_volume(d, left, right);
 
-  /* Suns, HPs, Linux, NEWS can't read the volume; oh well */
-  *left = *right = -1;
+#if defined(CDROMVOLREAD)
+  if(!ioctl(d->fd, CDROMVOLREAD, &v)) {
+    *left = unscale_volume((v.channel0 + v.channel2)/2, 100);
+    *right = unscale_volume((v.channel1 + v.channel3)/2, 100);
+  } else
+#endif
+    /* Suns, HPs, Linux, NEWS can't read the volume; oh well */
+    *left = *right = -1;
 
   return 0;
 } /* gen_get_volume() */
@@ -764,73 +800,4 @@ gen_get_cdtext(struct wm_drive *d, unsigned char **pp_buffer, int *p_buffer_leng
   return wm_scsi_get_cdtext(d, pp_buffer, p_buffer_lenght);
 } /* gen_get_cdtext() */
 
-  
-#ifdef BUILD_CDDA
-
-/*-------------------------------------------------------*
- *
- *
- *                    CDDA functions.
- *
- *
- *-------------------------------------------------------*/
-
-/*
- * Try to initialize the CDDA slave.  Returns 0 on success.
- */
-int
-gen_cdda_init( struct wm_drive *d )
-{
-  int	slavefds[2];
-  
-  if (d->cdda_slave > -1)
-    return (0);
-  
-  if (socketpair(AF_UNIX, SOCK_STREAM, 0, slavefds))
-    {
-      perror("socketpair");
-      return (-2);
-    }
-  
-  wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "gen_cdda_init(): going to fork\n" );
-
-  switch (fork()) {
-  case 0:
-    close(slavefds[0]);
-    dup2(slavefds[1], 1);
-    dup2(slavefds[1], 0);
-    close(slavefds[1]);
-    close(d->fd);
-
-    execlp(cddaslave_path, cddaslave_path, d->cd_device,
-      d->soundsystem, d->sounddevice, d->ctldevice, NULL);
-    perror(cddaslave_path);
-    exit(1);
-    
-  case -1:
-    close(slavefds[0]);
-    close(slavefds[1]);
-    perror("fork");
-    return (-3);
-  }
-  
-  close(slavefds[1]);
-  d->cdda_slave = slavefds[0];
-  
-  wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "gen_cdda_init(): wait for slave reply\n");
-
-  if (!cdda_get_ack(d->cdda_slave)) {
-    fprintf( stderr, "get_ack failed slave fd %i\n", d->cdda_slave );
-    d->cdda_slave = -1;
-    return -4;
-  }
-
-  wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "gen_cdda_init(): slave got reply\n");
-
-  return 0;
-} /* cdda_init() */
-  
-
-#endif /* BUILD_CDDA */
-
 #endif /* __linux__ */
