@@ -1,5 +1,5 @@
 /*
- * $Id: wm_helpers.c,v 1.3 2002/01/11 03:19:57 aseigo Exp $
+ * $Id: wm_helpers.c,v 1.5 2004/02/22 03:42:29 mueller Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -26,8 +26,6 @@
  *
  */
 
-static char wm_helpers_id[] = "$Id: wm_helpers.c,v 1.3 2002/01/11 03:19:57 aseigo Exp $";
-
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -105,12 +103,12 @@ void freeup( char **x )
 
 /* Copy into a malloced string. */
 void
-wm_strmcpy( char **t, char *s )
+wm_strmcpy( char **t, const char *s )
 {
 	wm_lib_message(WM_MSG_CLASS_MISC | WM_MSG_LEVEL_DEBUG, "wm_strmcpy(%s, '%s')\n", *t, s);
 	if (*t != NULL)
 	  {
-	    wm_lib_message(WM_MSG_CLASS_MISC | WM_MSG_LEVEL_DEBUG, "wm_strmcpy freeing pointer 0x%08X\n", *t);
+	    wm_lib_message(WM_MSG_CLASS_MISC | WM_MSG_LEVEL_DEBUG, "wm_strmcpy freeing pointer %p\n", *t);
 	    free(*t);
 	  }
 
@@ -121,13 +119,13 @@ wm_strmcpy( char **t, char *s )
 		exit(1);
 	}
 
-	wm_lib_message(WM_MSG_CLASS_MISC | WM_MSG_LEVEL_DEBUG, "wm_strmcpy finally copying (0x%08X, '%s')\n", *t, s);
+	wm_lib_message(WM_MSG_CLASS_MISC | WM_MSG_LEVEL_DEBUG, "wm_strmcpy finally copying (%p, '%s')\n", *t, s);
 	strncpy(*t, s, strlen(s));
 } /* wm_strmcpy() */
 
 /* Add to a malloced string. */
 void
-wm_strmcat( char **t, char *s)
+wm_strmcat( char **t, const char *s)
 {
 	int	len = strlen(s) + 1;
 
@@ -169,7 +167,7 @@ wm_strdup( char *s )
  */
 void wm_lib_set_verbosity( int level )
 {
-	if( WM_MSG_LEVEL_NONE <= level <= WM_MSG_LEVEL_DEBUG )
+	if( WM_MSG_LEVEL_NONE <= level && level <= WM_MSG_LEVEL_DEBUG )
 	{
 	 	wm_lib_verbosity = level;
 		wm_lib_message(WM_MSG_CLASS_MISC | WM_MSG_LEVEL_DEBUG, "Verbosity set to %d|%d\n", WM_MSG_LEVEL_DEBUG, level & WM_MSG_CLASS_ALL);
@@ -195,7 +193,7 @@ int wm_lib_get_verbosity( void )
  * defined in each module to reflect the correct message class.
  *
  */
-void wm_lib_message( unsigned int level, char *fmt, ... )
+void wm_lib_message( unsigned int level, const char *fmt, ... )
 {
 	va_list ap;
 	/* verbosity level */
