@@ -1,7 +1,7 @@
 #ifndef ASYNCSMTPSUBMIT_H
 #define ASYNCSMTPSUBMIT_H
 /*
-  Copyright (C) 2003 Richard Lrkng <nouseforaname@home.se>
+  Copyright (C) 2003-2004 Richard Lärkäng <nouseforaname@home.se>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -29,17 +29,16 @@ namespace KCDDB
     Q_OBJECT
 
     public:
-      AsyncSMTPSubmit(const QString&, uint, const QString&, const QString&);
+      AsyncSMTPSubmit(const QString& hostname, uint port, const QString& username,
+                      const QString& from, const QString& to);
       virtual ~AsyncSMTPSubmit();
 
-      virtual Result submit(const CDInfo &, const TrackOffsetList &);
     signals:
       void finished( CDDB::Result );
     protected slots:
-      void slotDataReq( KIO::Job *, QByteArray &data );
       void slotDone( KIO::Job * );
-    private:
-      bool sent;
+    protected:
+      virtual Result runJob(KIO::Job* job);
   } ;
 }
 
