@@ -16,12 +16,10 @@
 
 
 #include "decoderBaseObject_impl.h"
-#include "../mpeglib/lib/tplay/tplayPlugin.h"
+#include "../mpeglib/lib/decoder/tplayPlugin.h"
 
 
 
-using namespace Arts;
-
 class WAVPlayObject_impl: 
  virtual public DecoderBaseObject_impl,
  virtual public WAVPlayObject_skel {
