@@ -32,7 +32,6 @@ class NoatunApp : public KUniqueApplication
 {
 Q_OBJECT
 friend class Playlist;
-//friend class KCrash; // Why? [added by mETz, 13.07.2003]
 
 public:
 	NoatunApp();
@@ -56,9 +55,9 @@ public:
 	NoatunPreferences *preferencesBox() const { return mPref; }
 
 	/**
-	 * get a list of mimetypes aRts (noatun) can play, @ref KFileDialog
-	 * accepts this instead of the shell globs in the static functions,
-	 * so there ya go :)
+	 * @return a list of mimetypes aRts (and thus Noatun) can play
+	 * KFileDialog accepts this QString instead of the shell globs in
+	 * its static functions, make use of it :)
 	 **/
 	QString mimeTypes();
 
@@ -75,6 +74,19 @@ public:
 	virtual void commitData(QSessionManager &);
 	virtual void saveState(QSessionManager &);
 
+	/**
+	 * The three startup modes how noatun should behave when it is
+	 * restarted.
+	 *
+	 * Restore - it can restore the player's last state
+	 *
+	 * Play - it automatically starts playing the next file in the
+	 * playlist
+	 *
+	 * DontPlay - it doesn't start playing
+	 */
+	enum StartupPlayMode { Restore = 0, Play, DontPlay };
+
 signals:
 	/**
 	 * Tells you (a UI plugin) to hide
@@ -102,35 +114,69 @@ public slots:
 	void hideInterfaces();
 
 public: //options
+	/**
+	 * @deprecated Use startupPlayMode() instead
+	 */
 	bool autoPlay() const;
+	int startupPlayMode() const;
 	bool loopList() const;
 	bool oneInstance() const;
 	QString saveDirectory() const;
 	/**
 	 * @deprecated
-	 * now merged with @ref clearOnOpen
+	 * now merged with clearOnOpen()
 	 **/
 	bool clearOnStart() const;
+	/**
+	 * @return true if the playlist will be cleared when opening a
+	 * new file via commandline or file open dialog, false otherwise
+	 **/
 	bool clearOnOpen() const;
 	bool hackUpPlaylist() const;
+	/**
+	 * @return true if hardware-mixing is being used, false in case
+	 * software mixing is active
+	 **/
 	bool fastMixer() const;
 	QString titleFormat() const;
+	/**
+	 * @return true if remaining time is displayed to the user, false if
+	 * played time is displayed
+	 **/
 	bool displayRemaining() const;
 
 	void setOneInstance(bool);
 	void setLoopList(bool);
+	/**
+	 * @deprecated Use setStartupPlayMode() instead
+	 */
 	void setAutoPlay(bool);
+	void setStartupPlayMode(int mode);
 	void setSaveDirectory(const QString &);
 	void setRememberPositions(bool);
 	/**
 	 * @deprecated
-	 * now merged with @ref setClearOnOpen
+	 * now merged with setClearOnOpen()
 	 **/
 	void setClearOnStart(bool);
+	/**
+	 * Set if the playlist will be cleared when opening a
+	 * new file via commandline or file open dialog
+	 **/
 	void setClearOnOpen(bool);
 	void setHackUpPlaylist(bool);
+
+	/**
+	 * Set if hardware-mixing ("fast") or software-mixing ("slow") should be used
+	 **/
 	void setFastMixer(bool);
+
 	void setTitleFormat(const QString &);
+
+	/**
+	 * Pass true if remaining time should be displayed to the user, false if
+	 * played time should be displayed
+	 **/
 	void setDisplayRemaining(bool);
 
 	/**
@@ -178,12 +224,23 @@ public slots:
 	 * Exits Noatun
 	 */
 	void quit();
+	/**
+	 * Shows the standard file-open dialog
+	 */
 	void fileOpen();
+	/**
+	 * Shows the effects window
+	 */
 	void effectView();
+	/**
+	 * Shows the equalizer window
+	 */
 	void equalizerView();
 
 private:
 	void loadPlugins();
+	void saveEngineState();
+	void restoreEngineState();
 
 private:
 	Player *mPlayer;
@@ -206,9 +263,9 @@ private:
 // this is MAJOR.MINOR.PATCHLEVEL
 // and you developers better ignore patchlevel :)
 #define NOATUN_MAJOR 2
-#define NOATUN_MINOR 4
-#define NOATUN_PATCHLEVEL 1
+#define NOATUN_MINOR 8
+#define NOATUN_PATCHLEVEL 0
 
-#define NOATUN_VERSION "2.4.1"
+#define NOATUN_VERSION "2.8.0"
 
 #endif
