@@ -13,8 +13,5 @@
 
 extern "C"
 {
-    Plugin *create_plugin()
-    {
-	return new SimpleUI();
-    }
+	KDE_EXPORT Plugin *create_plugin() { return new SimpleUI(); }
 }
